#
# spec file for package python-sphinxcontrib-autoprogram
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%define psuffix       %{nil}
%if "%{flavor}" != ""
%define psuffix      -%{flavor}
%endif
%global short_name autoprogram
%{?sle15_python_module_pythons}
Name:           python-sphinxcontrib-%{short_name}%{psuffix}
Version:        0.1.9
Release:        1.2
%if "%{flavor}" == "" || "%{flavor}" == "test"
Summary:        Sphinx extension to document CLI programs
%endif
%if "%{flavor}" == "doc"
Summary:        Documentation for sphinxcontrib-autoprogram
%endif
License:        BSD-2-Clause
URL:            https://github.com/sphinx-contrib/%{short_name}
Source0:        %{URL}/archive/%{version}/python-sphinxcontrib-%{short_name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM skip-failing-test.patch gh#sphinx-contrib/autoprogram#54 mcepl@suse.com
# Switch off failing tests by the environmental variable SKIPTESTS
Patch1:         skip-failing-test.patch
BuildRequires:  %{python_module Sphinx >= 1.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx >= 1.2
BuildArch:      noarch
%if "%{flavor}" == "test"
BuildRequires:  %{python_module sphinxcontrib-autoprogram == %{version}}
BuildRequires:  %{python_module sphinxcontrib-websupport >= 1.0.1}
%endif
%if "%{flavor}" == "doc"
BuildRequires:  %{python_module sphinxcontrib-autoprogram == %{version}}
BuildRequires:  %{python_module sphinxcontrib-websupport}
%endif
%python_subpackages

%if "%{flavor}" == "doc"
%description
This package contains the documentation for the package
python-sphinxcontrib-autoprogram.
%endif
%if "%{flavor}" == "" || "%{flavor}" == "test"
%description
This contrib extension, sphinxcontrib.autoprogram, provides an automated way to
document CLI programs. It scans arparser.ArgumentParser object, and then expands
it into a set of .. program:: and .. option:: directives.
%endif

%prep
%autosetup -p1 -n %{short_name}-%{version} -p1

%build
%if "%{flavor}" == ""
%python_build
%endif
%if "%{flavor}" == "doc"
sphinx-build -b html -d doc/_build/doctrees doc doc/_build/html
rm doc/_build/html/objects.inv
%endif

%install
%if "%{flavor}" == ""
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if "%{flavor}" == "test"
export SKIPTESTS=1
%pyunittest -v sphinxcontrib.autoprogram.suite
%endif

%if "%{flavor}" == ""
%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/sphinxcontrib
%{python_sitelib}/sphinxcontrib_autoprogram-%{version}*-info
%{python_sitelib}/sphinxcontrib_autoprogram-%{version}*-nspkg.pth
%endif

%if "%{flavor}" == "doc"
%files %{python_files}
%license LICENSE
%doc doc/_build/html/*
%endif

%changelog
* Mon Jul  1 2024 Dirk Müller <dmueller@suse.com>
- update to 0.1.9:
  * Test against Python 3.12.
  * Drop support for Python 3.7.
- drop sphinx6.patch,
  python-sphinxcontrib-autoprogram-no-six.patch (upstream)
* Thu Apr  6 2023 pgajdos@suse.com
- do not require python-six
- added patches
  fix https://github.com/sphinx-contrib/autoprogram/issues/63
  + python-sphinxcontrib-autoprogram-no-six.patch
* Mon Feb 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add sphinx6.patch to support Sphinx >= 6.0, gh#sphinx-contrib/autoprogram#62
- Delete python-sphinxcontrib-autoprogram-python310.patch
- skip-failing-test.patch
- Update to 0.1.8
  * Test against Python 3.10, 3.11.
* Thu Dec  8 2022 Matej Cepl <mcepl@suse.com>
- Add skip-failing-test.patch skipping failing test
  gh#sphinx-contrib/autoprogram#54.
* Tue Feb 22 2022 pgajdos@suse.com
- fix build and introduced doc build flavor
- modified sources
  %% _multibuild
- added patches
  fix https://github.com/sphinx-contrib/autoprogram/pull/25
  + python-sphinxcontrib-autoprogram-python310.patch
* Tue Oct 12 2021 pgajdos@suse.com
- version update to 0.1.7
  Version 0.1.7
  - ------------
  - Publish to PyPI via Github Actions.
  Version 0.1.6
  - ------------
  - Dropped support for Python 2 and Pypy
  - Declare this extension safe for parallel reading
  - Migrate to Github Actions for CI [:issue:`28`, :pull:`32` by Langston Barrett]
  - Test against recent versions of Sphinx [:issue:`33`, :pull:`32` by Langston Barrett]
  - Format source code with Black [:issue:`30`, :pull:`32` by Langston Barrett]
  - Add documentation to the ``sdist`` [:issue:`26`, :pull:`32` by Langston Barrett]
  - Fixed unwanted ``<blockquote>`` tags in multi-line command descriptions that
    are indented to match surrounding code. [:pull:`21` by dgw]
- deleted patches
  - 0001-License-file-ci-skip.patch (upstreamed)
- added sources
  + _multibuild
* Tue Dec 18 2018 Dan Čermák <dcermak@suse.com>
- Run tests in %%check
* Thu Dec 13 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Dec 13 2018 Dan Čermák <dcermak@suse.com>
- Fix package name in spec file header
* Thu Dec 13 2018 Tomáš Chvátal <tchvatal@suse.com>
- Sort out with spec-cleaner, fix all FIXME mentions
* Wed Dec 12 2018 Dan Čermák <dcermak@suse.com>
- Initial release
